@@ -186,7 +186,7 @@ atk_component_contains (AtkComponent    *component,
  * Gets a reference to the accessible child, if one exists, at the
  * coordinate point specified by @x and @y.
  *
- * Returns: a reference to the accessible child, if one exists
+ * Returns: (transfer full): a reference to the accessible child, if one exists
  **/
 AtkObject*
 atk_component_ref_accessible_at_point (AtkComponent    *component,
@@ -385,7 +385,7 @@ atk_component_get_mdi_zorder (AtkComponent *component)
  * (fully opaque).
  *
  * Returns: An alpha value from 0 to 1.0, inclusive.
- * @Since: ATK 1.12
+ * Since: 1.12
  **/
 gdouble
 atk_component_get_alpha (AtkComponent    *component)
@@ -590,12 +590,6 @@ atk_component_real_get_size (AtkComponent *component,
   atk_component_get_extents (component, &x, &y, width, height, coord_type);
 }
 
-static gdouble
-atk_component_real_get_alpha (AtkComponent    *component)
-{
-    return (gdouble) 1.0;
-}
-
 static AtkRectangle *
 atk_rectangle_copy (const AtkRectangle *rectangle)
 {
